.. meta::
   :description: Gaitalytics Events.
   :keywords: gaitalytics, gait-analysis, mocap, c3d, gait-metrics, biomechanics, time-series, data-analysis, data, gait, references

Events
======


.. automodule:: gaitalytics.events
    :members: